Learn R Programming

BayesMed (version 1.0.1)

print.jzs_med: Print jzs_med output.

Description

Print the output of a jzs_med object.

Usage

"print"(x,...)

Arguments

x
a jzs_med object.
...
further arguments passed to or from other methods.

Value

The function returns a list with the following items:
EvidenceMediation
The posterior probability that the relation between the independent and the dependent variable is mediated by the specified mediator.
EvidenceFullMediation
The posterior probability that the relation between the independent and the dependent variable is fully mediated by the specified mediator and the direct effect of the independent variable on the dependent variable disappears after introducing the mediator.
BF_Mediation
The Bayes factor for mediation compared to no mediation. A value greater than one indicates evidence in favor of mediation, a value smaller than one indicates evidence against mediation.
BF_FullMediation
The Bayes factor for full mediation compared to no mediation. A value greater than one indicates evidence in favor of full mediation, a value smaller than one indicates evidence against full mediation.
BF_alpha
The Bayes factor for the existence of path alpha. A value greater than one indicates evidence that alpha exists, a value smaller than one indicates evidence that alpha does not exist.
BF_beta
The Bayes factor for the existence of path beta. A value greater than one indicates evidence that beta exists, a value smaller than one indicates evidence that beta does not exist.
BF_tau_accent
The Bayes factor for the existence of path tau_accent. A value greater than one indicates evidence that tau_accent exists, a value smaller than one indicates evidence that tau_accent does not exist.

Examples

Run this code
## Not run: 
# # simulate mediational data
# a <- .5 
# b <- .6
# t_prime <- .3
# 
# X <- rnorm(50,0,1)
# M <- a*X + rnorm(50,0,1)
# Y <- t_prime*X + b*M + rnorm(50,0,1)
# 
# # run jzs_med
# result <- jzs_med(independent=X,dependent=Y,mediator=M,SDmethod='dnorm')
# 
# # print result
# result
# ## End(Not run)

Run the code above in your browser using DataLab